@@ -7,7 +7,7 @@ use Parse::RecDescent;
 use Games::Dice::Roll20::Dice;
 use POSIX qw(ceil floor);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 has mock => (
     is      => 'rw',
@@ -158,10 +158,9 @@ sub roll {
 
 sub _reduce_list {
     my (@list) = @_;
-    my $sum = 0 + shift(@list);
+    my $sum = shift(@list);
     while (@list) {
-        my $op   = shift @list;
-        my $term = shift @list;
+        my ( $op, $term ) = splice( @list, 0, 2 );
         if ( $op eq '+' ) { $sum += $term; }
         elsif ( $op eq '-' ) { $sum -= $term }
         elsif ( $op eq '*' ) { $sum *= $term }
@@ -176,6 +175,10 @@ __END__
 
 =pod
 
+=for HTML <a href="https://travis-ci.org/mdom/Games-Dice-Roll20"><img src="https://travis-ci.org/mdom/Games-Dice-Roll20.svg?branch=master"></a>
+
+=for HTML <a href='https://coveralls.io/r/mdom/Games-Dice-Roll20?branch=master'><img src='https://coveralls.io/repos/mdom/Games-Dice-Roll20/badge.png?branch=master' alt='Coverage Status' /></a>
+
 =head1 NAME
 
 Games::Dice::Roll20 - Simulate dice rolls with Roll20's syntax
